@@ -36,22 +36,22 @@
 #include <tqregexp.h>
 #include <tqtextstream.h>
 
-#include <kmessagebox.h>
-#include <kaboutdata.h>
+#include <tdemessagebox.h>
+#include <tdeaboutdata.h>
 #include <kdebug.h>
 #include <kbookmarkmenu.h>
 #include <kbookmarkmanager.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <ksimpleconfig.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
 #include <kmimetype.h>
 #include <kprotocolinfo.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kstaticdeleter.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
 
 #include "kmplayerpartbase.h"
 #include "kmplayerview.h"
@@ -106,7 +106,7 @@ inline BookmarkManager::BookmarkManager(const TQString & bmfile)
 //-----------------------------------------------------------------------------
 
 PartBase::PartBase (TQWidget * wparent, const char *wname,
-                    TQObject * parent, const char *name, KConfig * config)
+                    TQObject * parent, const char *name, TDEConfig * config)
  : KMediaPlayer::Player (wparent, wname ? wname : "kde_kmplayer_view", parent, name ? name : "kde_kmplayer_part"),
    m_config (config),
    m_view (new View (wparent, wname ? wname : "kde_kmplayer_view")),
@@ -137,9 +137,9 @@ PartBase::PartBase (TQWidget * wparent, const char *wname,
     TQString localbmfile = locateLocal ("data", "kmplayer/bookmarks.xml");
     if (localbmfile != bmfile) {
         kdDebug () << "cp " << bmfile << " " << localbmfile << endl;
-        KProcess p;
+        TDEProcess p;
         p << "/bin/cp" << TQString(TQFile::encodeName (bmfile)) << TQString(TQFile::encodeName (localbmfile));
-        p.start (KProcess::Block);
+        p.start (TDEProcess::Block);
     }
     m_bookmark_manager = new BookmarkManager (localbmfile);
     m_bookmark_owner = new BookmarkOwner (this);
@@ -166,7 +166,7 @@ KDE_NO_EXPORT void PartBase::addBookMark (const TQString & t, const TQString & u
     m_bookmark_manager->emitChanged (b);
 }
 
-void PartBase::init (KActionCollection * action_collection) {
+void PartBase::init (TDEActionCollection * action_collection) {
     KParts::Part::setWidget (m_view);
     m_view->init (action_collection);
 #ifdef HAVE_NSPR
@@ -179,7 +179,7 @@ void PartBase::init (KActionCollection * action_collection) {
     connect (m_view, TQT_SIGNAL (urlDropped (const KURL::List &)), this, TQT_SLOT (openURL (const KURL::List &)));
     connectPlaylist (m_view->playList ());
     connectInfoPanel (m_view->infoPanel ());
-    new KAction (i18n ("Edit playlist &item"), 0, 0, TQT_TQOBJECT(m_view->playList ()), TQT_SLOT (editCurrent ()), action_collection, "edit_playlist_item");
+    new TDEAction (i18n ("Edit playlist &item"), 0, 0, TQT_TQOBJECT(m_view->playList ()), TQT_SLOT (editCurrent ()), action_collection, "edit_playlist_item");
 }
 
 void PartBase::connectPanel (ControlPanel * panel) {
@@ -885,7 +885,7 @@ KDE_NO_EXPORT bool PartBase::isPaused () {
     return doc && doc->state == Node::state_deferred;
 }
 
-KAboutData* PartBase::createAboutData () {
+TDEAboutData* PartBase::createAboutData () {
     KMessageBox::error(0L, "createAboutData", "KMPlayer");
     return 0;
 }
@@ -1679,7 +1679,7 @@ KDE_NO_EXPORT void URLSource::read (NodePtr root, TQTextStream & textstream) {
     }
 }
 
-KDE_NO_EXPORT void URLSource::kioData (KIO::Job * job, const TQByteArray & d) {
+KDE_NO_EXPORT void URLSource::kioData (TDEIO::Job * job, const TQByteArray & d) {
     SharedPtr <ResolveInfo> rinfo = m_resolve_info;
     while (rinfo && rinfo->job != job)
         rinfo = rinfo->next;
@@ -1711,7 +1711,7 @@ KDE_NO_EXPORT void URLSource::kioData (KIO::Job * job, const TQByteArray & d) {
     }
 }
 
-KDE_NO_EXPORT void URLSource::kioMimetype (KIO::Job * job, const TQString & mimestr) {
+KDE_NO_EXPORT void URLSource::kioMimetype (TDEIO::Job * job, const TQString & mimestr) {
     SharedPtr <ResolveInfo> rinfo = m_resolve_info;
     while (rinfo && rinfo->job != job)
         rinfo = rinfo->next;
@@ -1725,7 +1725,7 @@ KDE_NO_EXPORT void URLSource::kioMimetype (KIO::Job * job, const TQString & mime
         job->kill (false);
 }
 
-KDE_NO_EXPORT void URLSource::kioResult (KIO::Job * job) {
+KDE_NO_EXPORT void URLSource::kioResult (TDEIO::Job * job) {
     SharedPtr <ResolveInfo> previnfo, rinfo = m_resolve_info;
     while (rinfo && rinfo->job != job) {
         previnfo = rinfo;
@@ -1849,18 +1849,18 @@ bool URLSource::resolveURL (NodePtr m) {
              (url.protocol ().startsWith (TQString ("http")) || 
               url.protocol () == TQString::fromLatin1 ("media") ||
               url.protocol () == TQString::fromLatin1 ("remote")))) {
-        KIO::Job * job = KIO::get (url, false, false);
+        TDEIO::Job * job = TDEIO::get (url, false, false);
         job->addMetaData ("PropagateHttpHeader", "true");
         job->addMetaData ("errorPage", "false");
         m_resolve_info = new ResolveInfo (m, job, m_resolve_info);
-        connect (m_resolve_info->job, TQT_SIGNAL(data(KIO::Job*,const TQByteArray&)),
-                this, TQT_SLOT (kioData (KIO::Job *, const TQByteArray &)));
-        //connect( m_job, TQT_SIGNAL(connected(KIO::Job*)),
-        //         this, TQT_SLOT(slotConnected(KIO::Job*)));
-        connect(m_resolve_info->job, TQT_SIGNAL(mimetype(KIO::Job*,const TQString&)),
-                this, TQT_SLOT (kioMimetype (KIO::Job *, const TQString &)));
-        connect (m_resolve_info->job, TQT_SIGNAL (result (KIO::Job *)),
-                this, TQT_SLOT (kioResult (KIO::Job *)));
+        connect (m_resolve_info->job, TQT_SIGNAL(data(TDEIO::Job*,const TQByteArray&)),
+                this, TQT_SLOT (kioData (TDEIO::Job *, const TQByteArray &)));
+        //connect( m_job, TQT_SIGNAL(connected(TDEIO::Job*)),
+        //         this, TQT_SLOT(slotConnected(TDEIO::Job*)));
+        connect(m_resolve_info->job, TQT_SIGNAL(mimetype(TDEIO::Job*,const TQString&)),
+                this, TQT_SLOT (kioMimetype (TDEIO::Job *, const TQString &)));
+        connect (m_resolve_info->job, TQT_SIGNAL (result (TDEIO::Job *)),
+                this, TQT_SLOT (kioResult (TDEIO::Job *)));
         static_cast <View *> (m_player->view ())->controlPanel ()->setPlaying (true);
         m_player->updateStatus (i18n ("Connecting"));
         m_player->setLoaded (0);
@@ -1944,13 +1944,13 @@ KDE_NO_EXPORT bool RemoteObjectPrivate::download (const TQString & str) {
     }
     if (memory_cache->preserve (str)) {
         //kdDebug () << "downloading " << str << endl;
-        job = KIO::get (kurl, false, false);
-        connect (job, TQT_SIGNAL (data (KIO::Job *, const TQByteArray &)),
-                this, TQT_SLOT (slotData (KIO::Job *, const TQByteArray &)));
-        connect (job, TQT_SIGNAL (result (KIO::Job *)),
-                this, TQT_SLOT (slotResult (KIO::Job *)));
-        connect (job, TQT_SIGNAL (mimetype (KIO::Job *, const TQString &)),
-                this, TQT_SLOT (slotMimetype (KIO::Job *, const TQString &)));
+        job = TDEIO::get (kurl, false, false);
+        connect (job, TQT_SIGNAL (data (TDEIO::Job *, const TQByteArray &)),
+                this, TQT_SLOT (slotData (TDEIO::Job *, const TQByteArray &)));
+        connect (job, TQT_SIGNAL (result (TDEIO::Job *)),
+                this, TQT_SLOT (slotResult (TDEIO::Job *)));
+        connect (job, TQT_SIGNAL (mimetype (TDEIO::Job *, const TQString &)),
+                this, TQT_SLOT (slotMimetype (TDEIO::Job *, const TQString &)));
     } else {
         //kdDebug () << "download preserved " << str << endl;
         connect (memory_cache, TQT_SIGNAL (preserveRemoved (const TQString &)),
@@ -1972,12 +1972,12 @@ KDE_NO_EXPORT void RemoteObjectPrivate::clear () {
     }
 }
 
-KDE_NO_EXPORT void RemoteObjectPrivate::slotResult (KIO::Job * kjob) {
+KDE_NO_EXPORT void RemoteObjectPrivate::slotResult (TDEIO::Job * kjob) {
     if (!kjob->error ())
         memory_cache->add (url, data);
     else
         data.resize (0);
-    job = 0L; // signal KIO::Job::result deletes itself
+    job = 0L; // signal TDEIO::Job::result deletes itself
     remote_object->remoteReady (data);
 }
 
@@ -1992,7 +1992,7 @@ void RemoteObjectPrivate::cachePreserveRemoved (const TQString & str) {
 }
 
 KDE_NO_EXPORT
-void RemoteObjectPrivate::slotData (KIO::Job*, const TQByteArray& qb) {
+void RemoteObjectPrivate::slotData (TDEIO::Job*, const TQByteArray& qb) {
     if (qb.size ()) {
         int old_size = data.size ();
         data.resize (old_size + qb.size ());
@@ -2001,7 +2001,7 @@ void RemoteObjectPrivate::slotData (KIO::Job*, const TQByteArray& qb) {
 }
 
 KDE_NO_EXPORT
-void RemoteObjectPrivate::slotMimetype (KIO::Job *, const TQString & m) {
+void RemoteObjectPrivate::slotMimetype (TDEIO::Job *, const TQString & m) {
     mime = m;
 }
 
